References — timeawarepc 2022 documentation

# References

## Open Source Software Projects

### Python Packages

- pcalg in Python: Python implementation of PC algorithm.

- NiTime: Library of tools and algorithms for the analysis of time-series data from neuroscience experiments. Used for Granger Causality functions in this package. [5].

### R Packages

- kpcalg: Package for Kernel PC algorithm.

- pcalg: Package for PC algorithm.

## Papers

1

  Rahul Biswas and Eli Shlizerman. Statistical perspective on functional and causal neural connectomics: the time-aware pc algorithm. arXiv preprint arXiv:2204.04845, 2022.

2

  Rahul Biswas and Eli Shlizerman. Statistical perspective on functional and causal neural connectomics: a comparative study. Frontiers in Systems Neuroscience, 2022. doi:10.3389/fnsys.2022.817962.

3

  Markus Kalisch and Peter Bühlmann. Estimating high-dimensional directed acyclic graphs with the pc-algorithm. Journal of Machine Learning Research, 8(Mar):613–636, 2007.

4

  Clive WJ Granger. Investigating causal relations by econometric models and cross-spectral methods. Econometrica: journal of the Econometric Society, pages 424–438, 1969.

5

  Ariel Rokem, M Trumpis, and F Perez. Nitime: time-series analysis for neuroimaging data. In Proceedings of the 8th Python in Science Conference, 68–75. 2009. URL: http://nipy.org/nitime/.